NoWiredashInstanceFoundException class

Reported when WiredashAnalytics.trackEvent but no Wiredash widget is mounted.

This warning is only throw on the main isolate, where the Wiredash widget is expected to be always mounted.

Implemented types

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited