environment property

String? environment
final

The environment of your app, like 'prod', 'dev', 'staging'

When null, defaults to 'prod' for release builds and 'dev' for debug builds and emulators. To disable the automatic environment detection, set environment: 'prod'.

Setting an environment is useful to differentiate between different versions of your app allowing you to filter analytics and feedback by environment.

White-label apps can use this to differentiate between different clients, when they share the same Wiredash project.

The environment needs to be

  • at least 2 characters long, max 32 characters
  • only use lowercase a-z, - and _
  • start with a letter (a-z)

Implementation

final String? environment;